@@ -84,8 +84,11 @@ class VaultRepository:
         """TODO"""
         self._load()
         with open(self.unlocked_vault_file, 'w') as f_unlocked:
-            idx, _ = next(((i, e) for i, e in enumerate(self._storage) if e['key'] == entity.name), None)
-            self._storage[idx] = entity
+            t_entity = next(((i, e) for i, e in enumerate(self._storage) if e['key'] == entity.name), None)
+            if t_entity:
+                self._storage[t_entity[0]] = entity
+            else:
+                self._storage.append(entity)
             log.debug(f"Saved {len(self._storage)} entries from vault file")
             f_unlocked.write(f"[{','.join([str(e) for e in self._storage])}]")
 
